/* -*- mode:prolog; -*-
 ******************************************************************
 * $Id$
 * Copyright (C) 2002 by INRIA 
 * Author: Eric de la Clergerie <Eric.De_La_Clergerie@inria.fr>
 * ----------------------------------------------------------------
 *
 *  base.tag -- Base d'une grammaire TAG du franais
 *
 * ----------------------------------------------------------------
 * Description
 * 
 * ----------------------------------------------------------------
 */

%% Module DyALog pour grer les ancrages des arbres
:-require 'tag_generic.pl'.

%% Inclusion d'un fichier de dclarations pour les traits et les domaines finis
:-include 'header.plh'.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Partie declaration
%%   Celle-ci peut etre incluse dans un fichier separee, par example
%%   base.plh
%%   et remplace par la directive suivante
%% :-include 'header.plh'.

%% Generique pour les TAG
:-features( tag_tree, [ family, name, tree ] ).
:-features( tag_anchor, [name, coanchors, equations ] ).

%% Association des structures de traits aux non terminaux
:-tag_features(det,det{},det{}).
:-tag_features(adj,adj{},adj{}).
:-tag_features(n,n{},n{}).
:-tag_features(np,np{},np{}).
:-tag_features(vp,vp{},vp{}).
:-tag_features(v,v{},v{}).

%% Declarations des motifs d'ancrage
:-tag_anchor{ name => n0vn1pn2,
              coanchors => [ p2 ]
	    }.

:-tag_anchor{ name => np,
              equations => [[A,B]^(bot=np{num=>A,gen=>B} at np_) ]
	    }.

%% Fin des declarations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% La requte

?-recorded('N'(N)), tag_phrase(s,0,N).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Les arbres de la grammaire

%% Catgories trs lmentaires

tag_tree{ name => d,		% Determinant
	  family => d,
	  tree => tree <>det
	}.

tag_tree{ name => np,		% Pronoms et noms propres
	  family => np,
	  tree => tree id=np_ at <>np
	}.

tag_tree{ name => prep,		% Prepositions
	  family => prep,
	  tree => tree <>prep
	}.

%% Quelques arbres plus complexes

tag_tree{ name => dn,		% Determinant Nom
	  family => np,
	  tree => tree
	bot=np{num => X0} at
	np(
	   top=det{num => X0, gen => X1}
	  at det,
	   id=n_
	  and top=n{num => X0, gen => X1}
	  at <>n
	  )
	}.

tag_tree{ name => an,		% Adjectif Nom
	  family => adj,
	  tree => auxtree n(<>adj,*n)
	}.

tag_tree{ name => na,		% Nom Adjectif
	  family => adj,
	  tree => auxtree n(*n,<>adj)
	}.

tag_tree{ name=>n0v,		% Verbe intransitif
	  family=>n0v,
	  tree => tree s(id=np0 at np,vp(<>v))
	}.


tag_tree{ name=>n0vn1,		% Verbe transitif
	  family=>n0vn1,
	  tree => tree s(id=np0 at np,vp(<>v,id=np1 at np))
	}.

%% Famille prep des attachements prpositionnels
%% Arbre nppp
%% Jean fume le cigare de Sophie
%% Arbre vppp
%% Jean nage avec un tlescope

%% Famille n0vn1pn2
%% Verbes ditransitifs avec preposition
%% Jean donne une pomme  Sophie

%% Verbe intransitif en mode relatif
%% Arbre r0v de la famille n0v
%% Jean regarde Anne qui nage

%% Verbe transitif en mode relatif
%% Arbre r0vn1 de la famille n0vn1
%% Jean regarde Anne qui fume un cigare
%% Arbre r1n0v
%% Jean regarde le cigare que Anne fume

%% Verbe ditransitif en mode relatif
%% Arbre r0vn1pn2 de la famille n0vn1
%% Jean regarde Anne qui donne une pomme a Paul
%% Arbre r1n0vpn2
%% Jean regarde le cigare que Anne donne a Paul

%% Arbre vvp de la Famille vvp
%% Verbes introduisant une infinitive
%% Jean doit manger une pomme

%% Arbre ts1 de la famille ts1
%% Verbe introduisant une completive
%% Jean pense que Anne aime Paul

%% Verbes multi-catgoriss
%% Jean veut manger une pomme
%% Jean veut que Anne mange une pomme

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lexique syntaxique (lemmes)

tag_lemma('*DET*',det,tag_anchor{ name => d }).
tag_lemma('*PN*',np,tag_anchor{ name => np,
				equations => [bot = np{num=>sing} at np_]
			      }
	 ).
tag_lemma('*PREP*',prep,tag_anchor{ name => prep }).
tag_lemma('*PRON*',np,tag_anchor{ name => np }).
tag_lemma(cigare,n,tag_anchor{ name => np }).
tag_lemma(tlescope,n,tag_anchor{ name => np }).
tag_lemma(pomme,n,tag_anchor{ name => np }).
tag_lemma(manger,v,tag_anchor{ name => [n0v,n0vn1] }).
tag_lemma(regarder,v,tag_anchor{ name => n0vn1 }).
tag_lemma(fumer,v,tag_anchor{ name => [n0v,n0vn1] }).
tag_lemma(nager,v,tag_anchor{ name => n0v }).
tag_lemma(vert,adj,tag_anchor{ name => adj }).
tag_lemma(donner,v,tag_anchor{ name => n0vn1pn2, coanchors => [p2=] }).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lexique morphologique (mots)

tag_lexicon(le,'*DET*',det,det{kind=>def,gen=>masc,num=>sing}).
tag_lexicon(la,'*DET*',det,det{kind=>def,gen=>fem,num=>sing}).
tag_lexicon(un,'*DET*',det,det{kind=>indef,gen=>masc,num=>sing}).
tag_lexicon(une,'*DET*',det,det{kind=>indef,gen=>fem,num=>sing}).
tag_lexicon(les,'*DET*',det,det{kind=>def,num=>plur}).
tag_lexicon(des,'*DET*',det,det{kind=>indef,num=>plur}).

tag_lexicon('Pierre','*PN*',np,np{gen=>masc}).
tag_lexicon('Paul','*PN*',np,np{gen=>masc}).
tag_lexicon('Jean','*PN*',np,np{gen=>masc}).
tag_lexicon('Anne','*PN*',np,np{gen=>fem}).
tag_lexicon('Sophie','*PN*',np,np{gen=>fem}).

tag_lexicon(cigare,cigare,n,n{gen=>masc,num=>sing,anim=> (-)}).
tag_lexicon(cigares,cigare,n,n{gen=>masc,num=>plur,anim=> (-)}).
tag_lexicon(pomme,pomme,n,n{gen=>fem,num=>sing,anim=> (-)}).
tag_lexicon(pommes,pomme,n,n{gen=>fem,num=>plur,anim=> (-)}).
tag_lexicon(tlescope,tlescope,n,n{gen=>masc,num=>sing,anim=> (-)}).
tag_lexicon(tlescopes,tlescope,n,n{gen=>masc,num=>plur,anim=> (-)}).

tag_lexicon(fumer,fumer,v,v{mode=>inf}).
tag_lexicon(fume,fumer,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(fument,fumer,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(manger,manger,v,v{mode=>inf}).
tag_lexicon(mange,manger,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(mangent,manger,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(regarder,regarder,v,v{mode=>inf}).
tag_lexicon(regarde,regarder,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(regardent,regarder,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(nager,nager,v,v{mode=>inf}).
tag_lexicon(nage,nager,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(nagent,nager,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(donner,donner,v,v{mode=>inf}).
tag_lexicon(donne,donner,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(donnent,donner,v,v{num=>plu,mode=>mode[ind,subj]}).

tag_lexicon(vert,vert,adj,adj{gen=>masc,num=>sing}).
tag_lexicon(verts,vert,adj,adj{gen=>masc,num=>plur}).
tag_lexicon(verte,vert,adj,adj{gen=>fem,num=>sing}).
tag_lexicon(vertes,vert,adj,adj{gen=>fem,num=>plur}).

tag_lexicon(de,'*PREP*',prep,prep).
tag_lexicon(,'*PREP*',prep,prep).
tag_lexicon(avec,'*PREP*',prep,prep).

tag_lexicon(il,'*PRON*',np,np{gen=>masc,num=>sing}).


